@@ -99,6 +99,7 @@ sample_data_fid_dict = {
     'Colon':      '1oz1USuvIT7VNSmS2WhJuHDZQhkCH6IPY', 
     'CRC':        '1oz1USuvIT7VNSmS2WhJuHDZQhkCH6IPY',
     'Breast':     '158LUiHiJNFzYvqY-QzMUm5cvIznBrUAV', 
+    'BC':         '158LUiHiJNFzYvqY-QzMUm5cvIznBrUAV', 
     'BRCA':       '158LUiHiJNFzYvqY-QzMUm5cvIznBrUAV',
     'Pancreas':   '1OgTsyXczHQoV6PJyo_rfNBDJRRHXRhb-', 
     'PDAC':       '1OgTsyXczHQoV6PJyo_rfNBDJRRHXRhb-', 
@@ -184,17 +185,19 @@ def load_sample_data( file_id_or_tissue_name, file_type = 'tar.gz' ):
         return adata
 
 processed_sample_data_fid_dict = {
-    'Lung':       '1Xazyv4JhWlhYkDVk51KXaL3DDlAoxftp', 
-    'NSCLC':      '1Xazyv4JhWlhYkDVk51KXaL3DDlAoxftp',
-    'Intestine':  '1Xb_dzJDgt_RlkXk5nP0jgRUz_aFdP0G9', 
-    'Colon':      '1Xb_dzJDgt_RlkXk5nP0jgRUz_aFdP0G9', 
-    'CRC':        '1Xb_dzJDgt_RlkXk5nP0jgRUz_aFdP0G9',
-    'Breast':     '1XbX8Q3dH1kOWnM6ppms4BR2ukEAKYisB', 
-    'BRCA':       '1XbX8Q3dH1kOWnM6ppms4BR2ukEAKYisB',
-    'Pancreas':   '1XbYJQpyo8PaoL_vpjBt4YI5tTi8pgV5o', 
-    'PDAC':       '1XbYJQpyo8PaoL_vpjBt4YI5tTi8pgV5o', 
-    'Colitis-mm': '1QgdmySeTYQjW0NfNxbpaokU22VpEpcHA', 
-    'Colitis-hs': '1qRjo2iPlDVxF88umvpxiNGXk6jFK9dbb' 
+    'Lung':            '1Xazyv4JhWlhYkDVk51KXaL3DDlAoxftp', 
+    'NSCLC':           '1Xazyv4JhWlhYkDVk51KXaL3DDlAoxftp',
+    'Intestine':       '1Xb_dzJDgt_RlkXk5nP0jgRUz_aFdP0G9', 
+    'Colon':           '1Xb_dzJDgt_RlkXk5nP0jgRUz_aFdP0G9', 
+    'CRC':             '1Xb_dzJDgt_RlkXk5nP0jgRUz_aFdP0G9',
+    'Breast':          '1XbX8Q3dH1kOWnM6ppms4BR2ukEAKYisB', 
+    'BC':              '1XbX8Q3dH1kOWnM6ppms4BR2ukEAKYisB', 
+    'BRCA':            '1XbX8Q3dH1kOWnM6ppms4BR2ukEAKYisB',
+    'Pancreas':        '1XbYJQpyo8PaoL_vpjBt4YI5tTi8pgV5o', 
+    'PDAC':            '1XbYJQpyo8PaoL_vpjBt4YI5tTi8pgV5o', 
+    'Colitis-mm':      '1QgdmySeTYQjW0NfNxbpaokU22VpEpcHA', 
+    'Colitis-hs':      '1qRjo2iPlDVxF88umvpxiNGXk6jFK9dbb', 
+    'Colitis-mm-full': '1K7p0mFVRv9BIDkWZR41iWX2LzFcljWzg' 
 }
 
 def load_scoda_processed_anndata( tissue = None, file_type = 'tar.gz' ):
